@@ -2,10 +2,14 @@
 #  define LDSO_IMAGE "../ld-so/ld.so"
 #  define LDSO_CONF  "../util/ld.so.conf"
 #  define LDSO_CACHE "../util/ld.so.cache"
+#  define LDSO_PRELOAD "../util/ld.so.preload"
+#  define LDDSTUB    "../util/lddstub"
 #else
 #  define LDSO_IMAGE "/lib/ld.so"
 #  define LDSO_CONF  "/etc/ld.so.conf"
 #  define LDSO_CACHE "/etc/ld.so.cache"
+#  define LDSO_PRELOAD "/etc/ld.so.preload"
+#  define LDDSTUB    "/usr/lib/lddstub"
 #endif
 
 #define LDD_ARGV0    "__LDD_ARGV0"
