@@ -52,6 +52,8 @@ int _dl_map_cache(void)
   int fd;
   struct stat st;
   header_t *header;
+  libentry_t *libent;
+  int i, strtabsize;
 
   if (_dl_cache_addr == (caddr_t)-1)
     return -1;
@@ -77,17 +79,29 @@ int _dl_map_cache(void)
 
   header = (header_t *)_dl_cache_addr;
 
-  if (_dl_memcmp(header->magic, LDSO_CACHE_MAGIC, LDSO_CACHE_MAGIC_LEN))
+  if (_dl_cache_size < sizeof (header_t) ||
+      _dl_memcmp(header->magic, LDSO_CACHE_MAGIC, LDSO_CACHE_MAGIC_LEN) ||
+      _dl_memcmp(header->version, LDSO_CACHE_VER, LDSO_CACHE_VER_LEN) ||
+      _dl_cache_size < 
+        (sizeof (header_t) + header->nlibs * sizeof (libentry_t)) ||
+      _dl_cache_addr[_dl_cache_size-1] != '\0')
   {
     _dl_fdprintf(2, "%s: cache '%s' is corrupt\n", _dl_progname, LDSO_CACHE);
     goto fail;
   }
 
-  if (_dl_memcmp (header->version, LDSO_CACHE_VER, LDSO_CACHE_VER_LEN))
+  strtabsize = _dl_cache_size - sizeof (header_t) - 
+    header->nlibs * sizeof (libentry_t);
+  libent = (libentry_t *)&header[1];
+
+  for (i = 0; i < header->nlibs; i++)
   {
-    _dl_fdprintf(2, "%s: cache '%s' is not version %s\n",
-		 _dl_progname, LDSO_CACHE, LDSO_CACHE_VER);
-    goto fail;
+    if (libent[i].sooffset >= strtabsize ||
+	libent[i].liboffset >= strtabsize)
+    {
+      _dl_fdprintf(2, "%s: cache '%s' is corrupt\n", _dl_progname, LDSO_CACHE);
+      goto fail;
+    }
   }
 
   return 0;
